@@ -8,6 +8,7 @@ from django.db.models import QuerySet
 import json
 from .django import get_base_model, get_base_queryset
 from .django import my_api_assert_function
+from .django import conv_to_queryset
 
 
 class SingleConditionSearch:
@@ -368,9 +369,10 @@ class AdvancedSearchView(BaseListView):
         ret = self.get_key_from_query_dc_or_self(key, get_type='list')
         return ret
 
-    def get_list_queryset(self):
+    def get_queryset(self):
         query_dc = self.get_request_data()
-        ret = super().get_queryset()        # 默认返回所有
+        # ret = super().get_queryset()        # 默认返回所有
+        ret = conv_to_queryset(self.queryset)
 
         search_ls_dc = self.get_key_from_query_dc_or_self('search_ls_dc')        # 将列表查询search_ls转换为Q_add_ls中的条件
         Q_add_ls = self.get_Q_add_ls()
